function float2grayred(grayimage, filename, factor)
% take a float array in [-1,1] and write out gray scales for positive values and red for negative

  if nargin < 3
    factor = 1.0;
  end
  
  [width, height] = size(grayimage);
  
  outputimage = uint8(zeros(width, height, 3));     % RGB
  
  minssim = grayimage(1,1);
  maxssim = grayimage(1,1);
  
  for y = 1: height
    for x = 1: width
      minssim = min(minssim, grayimage(x,y));
      maxssim = max(maxssim, grayimage(x,y));
      if grayimage(x,y) >= 0
        f = real(grayimage(x,y)) * 255 * factor;  % need to use "real" here because Octave can return complex numbers sometimes.
        v = uint8( max(0, min(f, 255)) );
        outputimage(x,y,1) = v;             % set as gray scale value for positive gray scales in input image
        outputimage(x,y,2) = v;
        outputimage(x,y,3) = v;
      else
        f = -grayimage(x,y) * 255 * factor;
        v = uint8( max(0, min(f, 255)) );
        outputimage(x,y,1) = v;             % set as red color for negative values in input image
        outputimage(x,y,2) = 255-v;
        
        outputimage(x,y,3) = 0;
      end     
    end
  end

  fprintf("writing image: <%s>\n", filename);
  imwrite(outputimage, convertStringsToChars(filename));

end
