function [mssim_simplified, mssim, ssim_map_simplified, ssim_map, l_map, c_map, s_map] = ssimlcs(img1, img2)

if (nargin ~= 2)
   ssim_index = -Inf;
   ssim_map = -Inf;
   return;
end

if (size(img1) ~= size(img2))
   ssim_index = -Inf;
   ssim_map = -Inf;
   return;
end

[M N] = size(img1);

if ((M < 11) || (N < 11))
   ssim_index = -Inf;
   ssim_map = -Inf;
    return
end
window = fspecial('gaussian', 11, 1.5);	%
K(1) = 0.01;								      % default settings
K(2) = 0.03;								      %
L = 255;                                  %

C1 = (K(1)*L)^2;
C2 = (K(2)*L)^2;
window = window/sum(sum(window));
img1 = double(img1);
img2 = double(img2);

mu1   = filter2(window, img1, 'valid');
mu2   = filter2(window, img2, 'valid');
mu1_sq = mu1.*mu1;
mu2_sq = mu2.*mu2;
mu1_mu2 = mu1.*mu2;
sigma1_sq = filter2(window, img1.*img1, 'valid') - mu1_sq;
sigma2_sq = filter2(window, img2.*img2, 'valid') - mu2_sq;
sigma12 = filter2(window, img1.*img2, 'valid') - mu1_mu2;

ssim_map_simplified = ((2*mu1_mu2 + C1).*(2*sigma12 + C2))./((mu1_sq + mu2_sq + C1).*(sigma1_sq + sigma2_sq + C2));

l_map = (2 * mu1_mu2 + C1) ./ (mu1_sq + mu2_sq + C1);

c_map = (2 * sqrt(sigma1_sq) .* sqrt(sigma2_sq) + C2) ./ (sigma1_sq + sigma2_sq + C2);

s_map = (sigma12 + C2 * 0.5) ./ (sqrt(sigma1_sq) .* sqrt(sigma2_sq) + C2 * 0.5);

ssim_map = l_map .* c_map .* s_map;

mssim_simplified = mean2(ssim_map_simplified);
mssim = mean2(ssim_map);

return